@@ -1,3 +1,5 @@
+
+import sys
 import wx
 
 try:
@@ -5,6 +7,18 @@ try:
 except ImportError:
     print('-- warning. spec control software and SpecClient_gevent missing ? (normal if you are not at the beamline)')
 
+try:
+    sys.path.append('/users/blissadm/local/bliss.git')
+    from bliss.config import static
+
+    config = static.get_config()
+    from bliss.common import standard
+
+    session =  config.get('test')
+    #session.setup()
+except ImportError:
+    print('-- warning. BLISS control software is missing ? (normal if you are not at the beamline)')
+
 # --- ---------------  Plot limits board  parameters
 class MessageCommand(wx.Dialog):
     """
@@ -26,16 +40,19 @@ class MessageCommand(wx.Dialog):
 
         acceptbtn = wx.Button(self, -1, "OK")
         tospecbtn = wx.Button(self, -1, "Send to Spec")
+        toblissbtn = wx.Button(self, -1, "Send to Bliss")
         cancelbtn = wx.Button(self, -1, "Cancel")
 
         acceptbtn.Bind(wx.EVT_BUTTON, self.onAccept)
         cancelbtn.Bind(wx.EVT_BUTTON, self.onCancel)
         tospecbtn.Bind(wx.EVT_BUTTON, self.onCommandtoSpec)
+        toblissbtn.Bind(wx.EVT_BUTTON, self.onCommandtoBliss)
 
         btnssizer = wx.BoxSizer(wx.HORIZONTAL)
         btnssizer.Add(acceptbtn, 0, wx.ALL)
         btnssizer.Add(cancelbtn, 0, wx.ALL)
         btnssizer.Add(tospecbtn, 0, wx.ALL)
+        btnssizer.Add(toblissbtn, 0, wx.ALL)
 
         vbox = wx.BoxSizer(wx.VERTICAL)
         vbox.Add(txt1)
@@ -59,4 +76,22 @@ class MessageCommand(wx.Dialog):
 
         myspec.executeCommand(self.speccommand)
 
-        self.Close()
\ No newline at end of file
+        self.Close()
+        
+    def onCommandtoBliss(self, _):
+        
+        
+        m0=session.env_dict['m0']
+        m1=session.env_dict['m1']
+        print('toto--- in onCommandtoBliss')
+        print('dir(m0)', dir(m0))
+        print('dir(session)', dir(session))
+        print('\n\ntoto--- in onCommandtoBliss  retour')
+        
+        standard.mv(m0, 123)
+        # standard.mv(m0, 987)
+
+        print("\n\n*******************\n moved motors !!! \n*****************\n\n")
+
+        self.Close()
+        
\ No newline at end of file
